@@ -14,6 +14,7 @@
 #'   the values are taken from the function definition of the [caller
 #'   frame][caller_frame].
 #' @return The string supplied to `arg`.
+#' @importFrom utils adist
 #' @export
 #' @examples
 #' fn <- function(x = c("foo", "bar")) arg_match(x)
@@ -36,22 +37,32 @@ arg_match <- function(arg, values = NULL) {
     values <- eval_bare(values, get_env(fn))
   }
   if (!is_character(values)) {
-    abort("Internal error: `values` must be a character vector")
+    abort("Internal error: `values` must be a character vector.")
   }
   if (!is_character(arg)) {
-    abort(paste0(chr_quoted(arg_nm), " must be a character vector"))
+    abort(paste0(chr_quoted(arg_nm), " must be a character vector."))
+  }
+  if (length(arg) > 1 && !setequal(arg, values)) {
+    abort(arg_match_invalid_msg(arg_nm, values))
   }
 
   arg <- arg[[1]]
   i <- match(arg, values)
 
   if (is_na(i)) {
-    msg <- paste0(chr_quoted(arg_nm), " must be one of ")
-    msg <- paste0(msg, chr_enumerate(chr_quoted(values, "\"")))
+    msg <- arg_match_invalid_msg(arg_nm, values)
 
     i_partial <- pmatch(arg, values)
     if (!is_na(i_partial)) {
       candidate <- values[[i_partial]]
+    }
+
+    i_close <- adist(arg, values) / nchar(values)
+    if (any(i_close <= 0.5)) {
+      candidate <- values[[which.min(i_close)]]
+    }
+
+    if (exists("candidate")) {
       candidate <- chr_quoted(candidate, "\"")
       msg <- paste0(msg, "\n", "Did you mean ", candidate, "?")
     }
@@ -62,6 +73,12 @@ arg_match <- function(arg, values = NULL) {
   values[[i]]
 }
 
+arg_match_invalid_msg <- function(arg_nm, values) {
+  msg <- paste0(chr_quoted(arg_nm), " must be one of ")
+  msg <- paste0(msg, chr_enumerate(chr_quoted(values, "\"")), ".")
+  msg
+}
+
 chr_quoted <- function(chr, type = "`") {
   paste0(type, chr, type)
 }
