@@ -2,7 +2,7 @@
 #'
 #' @description
 #'
-#' * `scoped_options()` changes options for the duration of a stack
+#' * `local_options()` changes options for the duration of a stack
 #'   frame (by default the current one). Options are set back to their
 #'   old values when the frame returns.
 #'
@@ -20,13 +20,13 @@
 #'
 #' These functions are experimental.
 #'
-#' @param ... For `scoped_options()` and `push_options()`, named
+#' @param ... For `local_options()` and `push_options()`, named
 #'   values defining new option values. For `peek_options()`, strings
 #'   or character vectors of option names.
 #' @param .frame The environment of a stack frame which defines the
 #'   scope of the temporary options. When the frame returns, the
 #'   options are set back to their original values.
-#' @return For `scoped_options()` and `push_options()`, the old option
+#' @return For `local_options()` and `push_options()`, the old option
 #'   values. `peek_option()` returns the current value of an option
 #'   while the plural `peek_options()` returns a list of current
 #'   option values.
@@ -44,7 +44,7 @@
 #'
 #' # The scoped variant is useful within functions:
 #' fn <- function() {
-#'   scoped_options(my_option = 100)
+#'   local_options(my_option = 100)
 #'   peek_option("my_option")
 #' }
 #' fn()
@@ -53,36 +53,36 @@
 #' # The plural peek returns a named list:
 #' peek_options("my_option")
 #' peek_options("my_option", "digits")
-scoped_options <- function(..., .frame = caller_env()) {
+local_options <- function(..., .frame = caller_env()) {
   options <- list2(...)
   stopifnot(is_named(options))
 
   old <- options(options)
   options_lang <- call2(base::options, !!! old)
-  scoped_exit(!! options_lang, frame = .frame)
+  local_exit(!! options_lang, frame = .frame)
 
   invisible(old)
 }
 
-#' @rdname scoped_options
+#' @rdname local_options
 #' @param .expr An expression to evaluate with temporary options.
 #' @export
 with_options <- function(.expr, ...) {
-  scoped_options(...)
+  local_options(...)
   .expr
 }
-#' @rdname scoped_options
+#' @rdname local_options
 #' @export
 push_options <- function(...) {
   options(list2(...))
 }
-#' @rdname scoped_options
+#' @rdname local_options
 #' @export
 peek_options <- function(...) {
   names <- set_names(chr(...))
   map(names, getOption)
 }
-#' @rdname scoped_options
+#' @rdname local_options
 #' @param name An option name as string.
 #' @export
 peek_option <- function(name) {
@@ -102,9 +102,10 @@ peek_option <- function(name) {
 #'   escape hatch is useful in unit tests or to manually turn on
 #'   interactive features in RMarkdown outputs.
 #'
-#' * Whether knitr, an RStudio notebook, or testthat is in progress.
+#' * Whether knitr, an RStudio notebook, or testthat is in progress
+#'   (in which case `is_interactive()` returns `FALSE`).
 #'
-#' `with_interactive()` and `scoped_interactive()` set the global
+#' `with_interactive()` and `local_interactive()` set the global
 #' option conveniently.
 #'
 #' @export
@@ -137,14 +138,14 @@ is_interactive <- function() {
 #' @param value A single `TRUE` or `FALSE`. This overrides the return
 #'   value of `is_interactive()`.
 #' @export
-scoped_interactive <- function(value = TRUE, frame = caller_env()) {
-  scoped_options(rlang_interactive = value, .frame = frame)
+local_interactive <- function(value = TRUE, frame = caller_env()) {
+  local_options(rlang_interactive = value, .frame = frame)
 }
 #' @rdname is_interactive
 #' @param expr An expression to evaluate with interactivity set to
 #'   `value`.
 #' @export
 with_interactive <- function(expr, value = TRUE) {
-  scoped_interactive(value)
+  local_interactive(value)
   expr
 }
