@@ -9,6 +9,7 @@ sexp* rlang_ns_get(const char* name);
 // Initialised at load time
 static sexp* empty_spliced_arg = NULL;
 static sexp* splice_box_attrib = NULL;
+static sexp* quosures_attrib = NULL;
 
 sexp* rlang_new_splice_box(sexp* x) {
   sexp* out = KEEP(r_new_vector(r_type_list, 1));
@@ -83,6 +84,55 @@ struct dots_capture_info init_capture_info(enum dots_capture_type type,
 }
 
 
+static bool has_glue = false;
+sexp* rlang_glue_is_there() {
+  has_glue = true;
+  return r_null;
+}
+
+static bool has_curly(const char* str) {
+  for (char c = *str; c != '\0'; ++str, c = *str) {
+    if (c == '{') {
+      return true;
+    }
+  }
+  return false;
+}
+
+static void require_glue() {
+  sexp* call = KEEP(r_parse("is_installed('glue')"));
+  sexp* out = KEEP(r_eval(call, rlang_ns_env));
+
+  if (!r_is_scalar_logical(out)) {
+    r_abort("Internal error: Expected scalar logical from `requireNamespace()`.");
+  }
+  if (!r_lgl_get(out, 0)) {
+    r_abort("Can't use `{` symbols in LHS of `:=` if glue is not installed.");
+  }
+
+  FREE(2);
+}
+
+// Initialised at load time
+static sexp* glue_unquote_fn = NULL;
+
+static sexp* glue_unquote(sexp* lhs, sexp* env) {
+  if (r_typeof(lhs) != r_type_character ||
+      r_length(lhs) != 1 ||
+      !has_curly(r_chr_get_c_string(lhs, 0))) {
+    return lhs;
+  }
+
+  if (!has_glue) {
+    require_glue();
+  }
+
+  sexp* glue_unquote_call = KEEP(r_call2(glue_unquote_fn, lhs));
+  lhs = r_eval(glue_unquote_call, env);
+  FREE(1);
+  return lhs;
+}
+
 static sexp* def_unquote_name(sexp* expr, sexp* env) {
   int n_kept = 0;
   sexp* lhs = r_node_cadr(expr);
@@ -91,6 +141,7 @@ static sexp* def_unquote_name(sexp* expr, sexp* env) {
 
   switch (info.op) {
   case OP_EXPAND_NONE:
+    lhs = KEEP_N(glue_unquote(lhs, env), n_kept);
     break;
   case OP_EXPAND_UQ:
     lhs = KEEP_N(r_eval(info.operand, env), n_kept);
@@ -468,7 +519,7 @@ static bool should_auto_name(sexp* named) {
 static sexp* auto_name_call = NULL;
 
 static sexp* maybe_auto_name(sexp* x, sexp* named) {
-  sexp* names = r_vec_names(x);
+  sexp* names = r_names(x);
 
   if (should_auto_name(named) && (names == r_null || r_chr_has(names, ""))) {
     x = r_eval_with_x(auto_name_call, r_base_env, x);
@@ -486,7 +537,7 @@ static bool any_name(sexp* x, bool splice) {
     sexp* elt = r_node_car(x);
 
     if (splice && is_splice_box(elt)) {
-      if (r_vec_names(rlang_unbox(elt)) != r_null) {
+      if (r_names(rlang_unbox(elt)) != r_null) {
         return true;
       }
     }
@@ -527,7 +578,7 @@ sexp* dots_as_list(sexp* dots, struct dots_capture_info* capture_info) {
       check_named_splice(dots);
 
       elt = rlang_unbox(elt);
-      sexp* nms = r_vec_names(elt);
+      sexp* nms = r_names(elt);
 
       r_ssize n = r_length(elt);
       for (r_ssize i = 0; i < n; ++i) {
@@ -651,7 +702,7 @@ static sexp* dots_capture(struct dots_capture_info* capture_info, sexp* frame_en
 sexp* rlang_unescape_character(sexp*);
 
 static sexp* dots_finalise(struct dots_capture_info* capture_info, sexp* dots) {
-  sexp* nms = r_vec_names(dots);
+  sexp* nms = r_names(dots);
 
   if (nms != r_null) {
     // Serialised unicode points might arise when unquoting lists
@@ -722,9 +773,12 @@ sexp* rlang_quos_interp(sexp* frame_env,
   dots = KEEP(dots_as_list(dots, &capture_info));
   dots = KEEP(dots_finalise(&capture_info, dots));
 
-  r_push_class(dots, "quosures");
+  sexp* attrib = KEEP(r_new_node(r_names(dots), quosures_attrib));
+  r_node_poke_tag(attrib, r_names_sym);
+  r_poke_attributes(dots, attrib);
+  r_mark_object(dots);
 
-  FREE(3);
+  FREE(4);
   return dots;
 }
 
@@ -912,7 +966,9 @@ sexp* rlang_dots_pairlist(sexp* frame_env,
                                true);
 }
 
-void rlang_init_dots() {
+void rlang_init_dots(sexp* ns) {
+  glue_unquote_fn = r_eval(r_sym("glue_unquote"), ns);
+
   auto_name_call = r_parse("rlang:::quos_auto_name(x)");
   r_mark_precious(auto_name_call);
 
@@ -939,4 +995,17 @@ void rlang_init_dots() {
     r_mark_shared(empty_spliced_arg);
     FREE(1);
   }
+
+  {
+    sexp* quosures_class = KEEP(r_new_vector(r_type_character, 2));
+    r_chr_poke(quosures_class, 0, r_string("quosures"));
+    r_chr_poke(quosures_class, 1, r_string("list"));
+
+    quosures_attrib = r_pairlist(quosures_class);
+    r_mark_precious(quosures_attrib);
+    r_mark_shared(quosures_attrib);
+
+    r_node_poke_tag(quosures_attrib, r_class_sym);
+    FREE(1);
+  }
 }
