@@ -14,15 +14,17 @@ sexp* fns_function = NULL;
 sexp* fns_quote = NULL;
 
 void rlang_init_utils();
-void rlang_init_dots();
+void rlang_init_dots(sexp* ns);
 void rlang_init_expr_interp();
 void rlang_init_eval_tidy();
+void rlang_init_attr(sexp* ns);
 
 void rlang_init_internal(sexp* ns) {
   rlang_init_utils();
   rlang_init_dots(ns);
   rlang_init_expr_interp();
   rlang_init_eval_tidy();
+  rlang_init_attr(ns);
 
   rlang_zap = rlang_ns_get("zap!");
 
