@@ -105,7 +105,7 @@ static sexp* new_condition_names(sexp* data) {
     r_abort("Conditions must have named data fields");
   }
 
-  sexp* data_nms = r_vec_names(data);
+  sexp* data_nms = r_names(data);
 
   if (r_chr_has_any(data_nms, (const char* []) { "message", NULL })) {
     r_abort("Conditions can't have a `message` data field");
@@ -249,7 +249,7 @@ void r_init_library_cnd() {
   wng_signal_call = r_parse("warning(x)");
   r_mark_precious(wng_signal_call);
 
-  err_signal_call = r_parse("stop(x)");
+  err_signal_call = r_parse("rlang:::signal_abort(x)");
   r_mark_precious(err_signal_call);
 
   const char* cnd_signal_source =
